==> nnhl-0.1.2.tar.gz: nnhl-0.1.2/src/MesEng.h <==
	{ NMesNull,
		"" },

	/* Main win label */

	{ NMesLabelArt,
		"ARTICLE" },
	{ NMesLabelThr,
		"THREAD" },
	{ NMesLabelSite,
		"SITE" },
	{ NMesLabelSitePrev,
		"PREV" },
	{ NMesLabelSiteNext,
		"NEXT" },
	{ NMesLabelBar,
		"BAR" },

	/* Config win label */

	{ NMesLabelName,
		"Name" },
	{ NMesLabelUrl,
		"URL" },
	{ NMesLabelDownload,
		"Download" },
	{ NMesLabelDelete,
		"Delete" },
	{ NMesLabelUpdate,
		"Update" },
	{ NMesLabelNew,
		"New" },

	/* Socket */

	{ NMesRecvSrvrError,
		"I could not download data from server." },
	{ NMesRecvSrvrSendError,
		"I could not send request to server." },
	{ NMesRecvSrvrHeaderError,
		"I could not receive header from server." },

	/* Thread */

	{ NMesThreadCreateError,
		"I could not create thread." },

	/* Down Load */

	{ NMesHeadLineDefault,
		"I'm waiting now." },

	{ NMesDownLoadOpen,
		"I'm connecting server now." },
	{ NMesDownLoadOpenError,
		"I could not connect server." },
	{ NMesDownLoadRecv,
		"I'm downloading from server now." },
	{ NMesDownLoadClose,
		"I'm disconnecting server now." },
	{ NMesDownLoadCloseError,
		"I could not disconnect server." },
	{ NMesDownLoadPickUp,
		"I'm converting data now." },
	{ NMesDownLoadPickUpError,
		"I could not find news." },

	/* URL */

	{ NMesUrlExistNameError,
		"This name is exist already." },
	{ NMesUrlNotExistNameError,
		"This name isn't exist." },

	/* URL list */

	{ NMesUrlListSaveError,
		"I can't save config file." },

	/* URL name list */

	{ NMesUrlName_news2_2ch_net_news5plus_,
		"News+ the Middle East" },
	{ NMesUrlName_sports2_2ch_net_iraq_,
		"The Iraq" },
	{ NMesUrlName_news2_2ch_net_news5_,
		"Situation the Islam" },
	{ NMesUrlName_society_2ch_net_kokusai_,
		"World situation" },
	{ NMesUrlName_tmp2_2ch_net_bakanews_,
		"Foolish news" },
	{ NMesUrlName_tmp2_2ch_net_asia_,
		"News the Far East" },
	{ NMesUrlName_news2_2ch_net_news2_,
		"News discussion" },
	{ NMesUrlName_pc_2ch_net_pcnews_,
		"PC news" },
	{ NMesUrlName_comic_2ch_net_comicnews_,
		"Anime and Manga" },
	{ NMesUrlName_music3_2ch_net_musicnews_,
		"Music news" },
	{ NMesUrlName_news6_2ch_net_trafficinfo_,
		"Traffic infomation" },
	{ NMesUrlName_news4_2ch_net_news_,
		"News flash" },
	{ NMesUrlName_news5_2ch_net_newsplus_,
		"News flash+" },
	{ NMesUrlName_bbq_2ch_net_bbynews_,
		"Flash headline" },
	{ NMesUrlName_news7_2ch_net_femnewsplus_,
		"Female news+" },
	{ NMesUrlName_news6_2ch_net_mnewsplus_,
		"Flash+ Entertainment & Sports" },
	{ NMesUrlName_book_2ch_net_bizplus_,
		"Business news+" },
	{ NMesUrlName_news8_2ch_net_eqplus_,
		"An earthquake report+" },
	{ NMesUrlName_news8_2ch_net_eq_,
		"An earthquake report" },

	/* Copyright */

	{ NMesAboutGame,
		"ܥץϥե꡼եȥǤ\n"
		"ʤϡ Free Software Foundation ɽ"
		" GNU ̸ͭѵΡ֥С󣲡"
		"ϤʹߤγƥС椫餤줫򤷡"
		"ΥС˽äܥץ"
		"ۤޤѹ뤳ȤǤޤ\n"
		"\n"
		"ܥץͭѤȤϻפޤۤˤäƤϡ"
		"ԾڤŪŬˤĤƤΰۤݾڤޤ,"
		"ʤݾڤԤʤޤ\n"
		"ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ\n"
		"\n"
		"ʤϡܥץȰ GNU ̸ͭѵ"
		"μ̤äƤϤǤǤʤϡ\n"
		"  Free Software Foundation, Inc.,\n"
		"  59 Temple Place, Suite 330, Boston, MA 02111-1307, USA\n"
		"ؼ񤤤Ƥ\n"
	},

==> nnhl-0.1.3.tar.gz: nnhl-0.1.3/src/MesEng.h <==

#define STR_ARTICLE	"Article"
#define STR_THREAD	"Thread"
#define STR_SITE	"Site"

	{ NMesNull,
		"" },

	/* Main win label */

	{ NMesLabelArt,
		STR_ARTICLE },
	{ NMesLabelThr,
		STR_THREAD },
	{ NMesLabelSite,
		STR_SITE },
	{ NMesLabelSitePrev,
		"PREV" },
	{ NMesLabelSiteNext,
		"NEXT" },
	{ NMesLabelBar,
		"BAR" },

	/* Config win label */

	{ NMesLabelName,
		"Name" },
	{ NMesLabelUrl,
		"URL" },
	{ NMesLabelDownload,
		"Download" },
	{ NMesLabelEncoding,
		"Encoding" },
	{ NMesLabelSkipArt,
		STR_ARTICLE " per " STR_THREAD },

	{ NMesLabelDelete,
		"Delete" },
	{ NMesLabelUpdate,
		"Update" },
	{ NMesLabelNew,
		"New" },

	{ NMesLabelOrder,
		"Order" },
	{ NMesLabelUp,
		"Up" },
	{ NMesLabelDown,
		"Down" },
	{ NMesLabelTop,
		"Top" },
	{ NMesLabelBottom,
		"Bottom" },

	/* Socket */

	{ NMesRecvSrvrError,
		"I could not download data from server." },
	{ NMesRecvSrvrSendError,
		"I could not send request to server." },
	{ NMesRecvSrvrHeaderError,
		"I could not receive header from server." },

	/* Thread */

	{ NMesThreadCreateError,
		"I could not create thread." },

	/* Down Load */

	{ NMesHeadLineDefault,
		"I'm waiting now." },

	{ NMesDownLoadOpen,
		"I'm connecting server now." },
	{ NMesDownLoadOpenError,
		"I could not connect server." },
	{ NMesDownLoadRecv,
		"I'm downloading from server now." },
	{ NMesDownLoadClose,
		"I'm disconnecting server now." },
	{ NMesDownLoadCloseError,
		"I could not disconnect server." },
	{ NMesDownLoadPickUp,
		"I'm converting data now." },
	{ NMesDownLoadPickUpError,
		"I could not find news." },

	/* URL */

	{ NMesUrlExistNameError,
		"This name is exist already." },
	{ NMesUrlNotExistNameError,
		"This name isn't exist." },

	/* Config file */

	{ NMesSaveError,
		"I can't save config file." },
	{ NMesLoadVerError,
		"I can't correspond save config file." },

	/* URL name list */

	{ NMesUrlName_news2_2ch_net_news5plus_,
		"News+ the Middle East" },
	{ NMesUrlName_sports2_2ch_net_iraq_,
		"The Iraq" },
	{ NMesUrlName_news2_2ch_net_news5_,
		"Situation the Islam" },
	{ NMesUrlName_society_2ch_net_kokusai_,
		"World situation" },
	{ NMesUrlName_tmp2_2ch_net_bakanews_,
		"Foolish news" },
	{ NMesUrlName_tmp2_2ch_net_asia_,
		"News the Far East" },
	{ NMesUrlName_news2_2ch_net_news2_,
		"News discussion" },
	{ NMesUrlName_pc_2ch_net_pcnews_,
		"PC news" },
	{ NMesUrlName_comic_2ch_net_comicnews_,
		"Anime and Manga" },
	{ NMesUrlName_music3_2ch_net_musicnews_,
		"Music news" },
	{ NMesUrlName_news6_2ch_net_trafficinfo_,
		"Traffic infomation" },
	{ NMesUrlName_news4_2ch_net_news_,
		"News flash" },
	{ NMesUrlName_news5_2ch_net_newsplus_,
		"News flash+" },
	{ NMesUrlName_bbq_2ch_net_bbynews_,
		"Flash headline" },
	{ NMesUrlName_news7_2ch_net_femnewsplus_,
		"Female news+" },
	{ NMesUrlName_news6_2ch_net_mnewsplus_,
		"Flash+ Entertainment & Sports" },
	{ NMesUrlName_book_2ch_net_bizplus_,
		"Business news+" },
	{ NMesUrlName_news8_2ch_net_eqplus_,
		"An earthquake report+" },
	{ NMesUrlName_news8_2ch_net_eq_,
		"An earthquake report" },

	/* Copyright */

	{ NMesAboutGame,
		"ܥץϥե꡼եȥǤ\n"
		"ʤϡ Free Software Foundation ɽ"
		" GNU ̸ͭѵΡ֥С󣲡"
		"ϤʹߤγƥС椫餤줫򤷡"
		"ΥС˽äܥץ"
		"ۤޤѹ뤳ȤǤޤ\n"
		"\n"
		"ܥץͭѤȤϻפޤۤˤäƤϡ"
		"ԾڤŪŬˤĤƤΰۤݾڤޤ,"
		"ʤݾڤԤʤޤ\n"
		"ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ\n"
		"\n"
		"ʤϡܥץȰ GNU ̸ͭѵ"
		"μ̤äƤϤǤǤʤϡ\n"
		"  Free Software Foundation, Inc.,\n"
		"  59 Temple Place, Suite 330, Boston, MA 02111-1307, USA\n"
		"ؼ񤤤Ƥ\n"
	},

#undef STR_ARTICLE
#undef STR_THREAD
#undef STR_SITE
